cylp: Python interface for CLP, CBC, and CGL
============================================

Description
-----------

Python interface for CLP, CBC, and CGL

License
-------

Eclipse Public License (EPL) version 2 (without a Secondary Licenses Notice).

Note: This license is incompatible with the GPL according to
https://www.gnu.org/licenses/license-list.html#EPL2;
see also the discussion in :issue:`26511`.

Upstream Contact
----------------

https://pypi.org/project/cylp/

